pub unsafe extern "C" fn CFArrayGetValueAtIndex(
theArray: CFArrayRef,
idx: CFIndex,
) -> *const c_voidExpand description
@function CFArrayGetValueAtIndex Retrieves the value at the given index. @param theArray The array to be queried. If this parameter is not a valid CFArray, the behavior is undefined. @param idx The index of the value to retrieve. If the index is outside the index space of the array (0 to N-1 inclusive, where N is the count of the array), the behavior is undefined. @result The value with the given index in the array.