CFArrayGetValues

Function CFArrayGetValues 

pub unsafe extern "C" fn CFArrayGetValues(
    theArray: CFArrayRef,
    range: CFRange,
    values: *mut *const c_void,
)
@function CFArrayGetValues Fills the buffer with values from the array. @param theArray The array to be queried. If this parameter is not a valid CFArray, the behavior is undefined. @param range The range of values within the array to retrieve. If the range location or end point (defined by the location plus length minus 1) is outside the index space of the array (0 to N-1 inclusive, where N is the count of the array), the behavior is undefined. If the range length is negative, the behavior is undefined. The range may be empty (length 0), in which case no values are put into the buffer. @param values A C array of pointer-sized values to be filled with values from the array. The values in the C array are ordered in the same order in which they appear in the array. If this parameter is not a valid pointer to a C array of at least range.length pointers, the behavior is undefined.