CFAttributedStringBeginEditing

Function CFAttributedStringBeginEditing 

pub unsafe extern "C" fn CFAttributedStringBeginEditing(
    aStr: CFMutableAttributedStringRef,
)
@function CFAttributedStringBeginEditing In cases where attributed string might do a bunch of work to assure self-consistency, CFAttributedStringBeginEditing/CFAttributedStringEndEditing allow disabling that to allow deferring and coalescing any work. It’s a good idea to call these around a set of related mutation calls which don’t require the string to be in consistent state in between. These calls can be nested.