CFCharacterSetRemoveCharactersInRange

Function CFCharacterSetRemoveCharactersInRange 

pub unsafe extern "C" fn CFCharacterSetRemoveCharactersInRange(
    theSet: CFMutableCharacterSetRef,
    theRange: CFRange,
)
@function CFCharacterSetRemoveCharactersInRange Removes the given range from the charaacter set. @param theSet The character set from which the range is to be removed. If this parameter is not a valid mutable CFCharacterSet, the behavior is undefined. @param theRange The range to remove from the character set. It accepts the range in 32-bit in the UTF-32 format. The valid character point range is from 0x00000 to 0x10FFFF. If the range is outside of the valid Unicode character point, the behavior is undefined.