CFCharacterSetUnion

Function CFCharacterSetUnion 

pub unsafe extern "C" fn CFCharacterSetUnion(
    theSet: CFMutableCharacterSetRef,
    theOtherSet: CFCharacterSetRef,
)
@function CFCharacterSetUnion Forms the union with the given character set. @param theSet The destination character set into which the union of the two character sets is stored. If this parameter is not a valid mutable CFCharacterSet, the behavior is undefined. @param theOtherSet The character set with which the union is formed. If this parameter is not a valid CFCharacterSet, the behavior is undefined.