CFDictionaryRemoveValue

Function CFDictionaryRemoveValue 

pub unsafe extern "C" fn CFDictionaryRemoveValue(
    theDict: CFMutableDictionaryRef,
    key: *const c_void,
)
@function CFDictionaryRemoveValue Removes the value of the key from the dictionary. @param theDict The dictionary from which the value is to be removed. If this parameter is not a valid mutable CFDictionary, the behavior is undefined. @param key The key of the value to remove from the dictionary. If a key which matches this key is present in the dictionary, the key-value pair is removed from the dictionary, otherwise this function does nothing (“remove if present”).