CFErrorCopyRecoverySuggestion

Function CFErrorCopyRecoverySuggestion 

pub unsafe extern "C" fn CFErrorCopyRecoverySuggestion(
    err: CFErrorRef,
) -> CFStringRef
@function CFErrorCopyRecoverySuggestion @abstract Returns a human presentable recovery suggestion for the error. May return NULL. CFError creators should strive to make sure the return value is human-presentable and localized by providing a value for kCFErrorLocalizedRecoverySuggestionKey at the time of CFError creation. @discussion This is the string that can be displayed as the “informative” (aka “secondary”) message on an alert panel. By default this looks for kCFErrorLocalizedRecoverySuggestionKey in the user info. Toll-free bridged NSError instances might provide additional behaviors for manufacturing this value. If no user-presentable string is available, returns NULL. Example Description: “Could not save file ‘Letter’ in folder ‘Documents’ because the volume ‘MyDisk’ doesn’t have enough space.” Corresponding RecoverySuggestion: “Remove some files from the volume and try again.” @param err The CFError whose recovery suggestion is to be returned. If this reference is not a valid CFError, the behavior is undefined. @result A CFString with the localized, end-user presentable recovery suggestion of the CFError, or NULL.