pub unsafe extern "C" fn CFStringTokenizerCreate(
alloc: CFAllocatorRef,
string: CFStringRef,
range: CFRange,
options: CFOptionFlags,
locale: CFLocaleRef,
) -> CFStringTokenizerRefExpand description
@function CFStringTokenizerCreate @abstract Creates a tokenizer instance. @param alloc The CFAllocator which should be used to allocate memory for the tokenizer and its storage for values. This parameter may be NULL in which case the current default CFAllocator is used. @param string The string to tokenize. @param range The range of characters within the string to be tokenized. The specified range must not exceed the length of the string. @param options Use one of the Tokenization Unit options to specify how the string should be tokenized. Optionally specify one or more attribute specifiers to tell the tokenizer to prepare specified attributes when it tokenizes the string. @param locale The locale to specify language or region specific behavior. Pass NULL if you want tokenizer to identify the locale automatically. @result A reference to the new CFStringTokenizer.