JSGlobalContextSetUncaughtExceptionHandler

Function JSGlobalContextSetUncaughtExceptionHandler 

pub unsafe extern "C" fn JSGlobalContextSetUncaughtExceptionHandler(
    ctx: JSGlobalContextRef,
    handler: JSUncaughtExceptionHandler,
)
@function @abstract Sets the callback function that will be called when an uncaught exception occurs. @param ctx The JSGlobalContext whose uncaught exception callback you want to set. @param callback The JSObjectRef to call when an uncaught exception occurs. Pass NULL to remove the callback.