pub unsafe extern "C" fn JSLoadAndEvaluateModuleFromSource(
ctx: JSContextRef,
module: JSStringRef,
sourceURLString: JSStringRef,
startingLineNumber: c_int,
exception: *mut JSValueRef,
)Expand description
@function JSLoadAndEvaluateModuleFromSource @abstract Evaluates a string of JavaScript as a module. @param ctx The execution context to use. @param module A JSString containing the module code to evaluate. @param sourceURLString A JSString containing a URL for the script’s source file. This is used by debuggers and when reporting exceptions. Pass NULL if you do not care to include source file information. @param startingLineNumber An integer value specifying the script’s starting line number in the file located at sourceURL. This is only used when reporting exceptions. The value is one-based, so the first line is line 1 and invalid values are clamped to 1. @param exception A pointer to a JSValueRef in which to store an exception, if any. Pass NULL if you do not care to store an exception.