pub type CFBinaryHeapApplierFunction = Option<unsafe extern "C" fn(val: *const c_void, context: *mut c_void)>;Expand description
@typedef CFBinaryHeapApplierFunction Type of the callback function used by the apply functions of CFBinaryHeap. @param val The current value from the binary heap. @param context The user-defined context parameter given to the apply function.
Aliased Type
pub enum CFBinaryHeapApplierFunction {
None,
Some(unsafe extern "C" fn(*const c_void, *mut c_void)),
}