pub type CFCharacterSetRef = *const __CFCharacterSet;Expand description
@typedef CFCharacterSetRef This is the type of a reference to immutable CFCharacterSets.
pub type CFCharacterSetRef = *const __CFCharacterSet;@typedef CFCharacterSetRef This is the type of a reference to immutable CFCharacterSets.