pub unsafe extern "C" fn CFAttributedStringReplaceAttributedString(
aStr: CFMutableAttributedStringRef,
range: CFRange,
replacement: CFAttributedStringRef,
)Expand description
@function CFAttributedStringReplaceAttributedString Replaces the attributed substring over the specified range with the attributed string specified in replacement. range should be valid. To delete a range of the attributed string, call CFAttributedStringReplaceString() with empty string and specified range.