pub unsafe extern "C" fn JSLoadModule(
ctx: JSContextRef,
moduleKey: JSStringRef,
exception: *mut JSValueRef,
)Expand description
@function JSLoadModule @abstract Loads a module. @param ctx The execution context to use. @param moduleKey A JSString containing the module key to load. @param exception A pointer to a JSValueRef in which to store an exception, if any. Pass NULL if you do not care to store an exception.